# 6R Framework
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/6r#overview)
  * [What is 6R?](https://help.sap.com/docs/leanix/ea/6r#what-is-6r?)
  * [How to Implement 6R in SAP LeanIX](https://help.sap.com/docs/leanix/ea/6r#how-to-implement-6r-in-sap-leanix)
  * [Accessing the 6R Attribute in Fact Sheets](https://help.sap.com/docs/leanix/ea/6r#accessing-the-6r-attribute-in-fact-sheets)
  * [Applying the 6R Classification](https://help.sap.com/docs/leanix/ea/6r#applying-the-6r-classification)
  * [Using the 6R Classification for Application Portfolio Assessment](https://help.sap.com/docs/leanix/ea/6r#using-the-6r-classification-for-application-portfolio-assessment)
